@@ -1,8 +1,6 @@
 /** \file Environment.h
 \brief Define the environment variable and global function
 \author alpha_one_x86
-\version 0.3
-\date 2010
 \licence GPL3, see the file COPYING */
 
 #include "Variable.h"
@@ -13,7 +11,11 @@
 #include "DebugEngineMacro.h"
 
 #ifdef ULTRACOPIER_VERSION_PORTABLE
-	#define ULTRACOPIER_VERSION_PORTABLE_BOOL true
+    #define ULTRACOPIER_VERSION_PORTABLE_BOOL true
 #else
-	#define ULTRACOPIER_VERSION_PORTABLE_BOOL false
+    #define ULTRACOPIER_VERSION_PORTABLE_BOOL false
+#endif
+
+#ifdef ULTRACOPIER_PLUGIN_ALL_IN_ONE
+#undef ULTRACOPIER_PLUGIN_IMPORT_SUPPORT
 #endif
