@@ -1,8 +1,6 @@
 /** \file LocalPluginOptions.h
 \brief To bind the options of the plugin, into unique group options
 \author alpha_one_x86
-\version 0.3
-\date 2010
 \licence GPL3, see the file COPYING */
 
 #ifndef LOCALPLUGINOPTIONS_H
@@ -21,25 +19,24 @@
 */
 class LocalPluginOptions : public OptionInterface
 {
-	Q_OBJECT
+    Q_OBJECT
 public:
-	explicit LocalPluginOptions(const QString &group);
-	~LocalPluginOptions();
-	/// \brief To add option group to options
-	bool addOptionGroup(const QList<QPair<QString, QVariant> > &KeysList);
-	/*/// \brief To remove option group to options, removed to the load plugin
-	bool removeOptionGroup();*/
-	/// \brief To get option value
-	QVariant getOptionValue(const QString &variableName);
-	/// \brief To set option value
-	void setOptionValue(const QString &variableName,const QVariant &value);
+    explicit LocalPluginOptions(const std::string &group);
+    ~LocalPluginOptions();
+    /// \brief To add option group to options
+    bool addOptionGroup(const std::vector<std::pair<std::string, std::string> > &KeysList);
+    /*/// \brief To remove option group to options, removed to the load plugin
+    bool removeOptionGroup();*/
+    /// \brief To get option value
+    std::string getOptionValue(const std::string &variableName) const;
+    /// \brief To set option value
+    void setOptionValue(const std::string &variableName,const std::string &value);
 protected:
-	//for the options
-	OptionEngine *options;
-	QString group;
-	bool groupOptionAdded;
+    //for the options
+    std::string group;
+    bool groupOptionAdded;
 /*public slots:-> disabled because the value will not externaly changed, then useless notification
-	void newOptionValue(QString group,QString variable,QVariant value);*/
+    void newOptionValue(QString group,QString variable,QVariant value);*/
 };
 
 #endif // LOCALPLUGINOPTIONS_H
